numpy.generic
=============

.. currentmodule:: numpy

.. autoclass:: generic

   

   .. HACK
      .. autosummary::
         :toctree:
      
         generic.__init__
         generic.all
         generic.any
         generic.argmax
         generic.argmin
         generic.argsort
         generic.astype
         generic.byteswap
         generic.choose
         generic.clip
         generic.compress
         generic.conj
         generic.conjugate
         generic.copy
         generic.cumprod
         generic.cumsum
         generic.diagonal
         generic.dump
         generic.dumps
         generic.fill
         generic.flatten
         generic.getfield
         generic.item
         generic.itemset
         generic.max
         generic.mean
         generic.min
         generic.newbyteorder
         generic.nonzero
         generic.prod
         generic.ptp
         generic.put
         generic.ravel
         generic.repeat
         generic.reshape
         generic.resize
         generic.round
         generic.searchsorted
         generic.setfield
         generic.setflags
         generic.sort
         generic.squeeze
         generic.std
         generic.sum
         generic.swapaxes
         generic.take
         generic.tofile
         generic.tolist
         generic.tostring
         generic.trace
         generic.transpose
         generic.var
         generic.view



   

   .. HACK
      .. autosummary::
         :toctree:
      
         generic.T
         generic.base
         generic.data
         generic.dtype
         generic.flags
         generic.flat
         generic.imag
         generic.itemsize
         generic.nbytes
         generic.ndim
         generic.real
         generic.shape
         generic.size
         generic.strides

